@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2009 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,9 @@
       Detrend    detrend         Detrend
 */
 
+#if defined (_OPENMP)
+#  include <omp.h>
+#endif
 
 #include "cdi.h"
 #include "cdo.h"
@@ -28,7 +31,7 @@
 #include "pstream.h"
 
 
-#define  NALLOC_INC  1000
+#define  NALLOC_INC  1024
 
 
 static
@@ -66,6 +69,7 @@ void detrend(int nts, double missval1, double *array1, double *array2)
 void *Detrend(void *argument)
 {
   static char func[] = "Detrend";
+  int ompthID;
   int gridsize;
   int nrecs;
   int gridID, varID, levelID, recID;
@@ -79,8 +83,13 @@ void *Detrend(void *argument)
   int nvars, nlevel;
   int *vdate = NULL, *vtime = NULL;
   double missval;
-  double *array1, *array2;
-  FIELD ***vars = NULL;
+  field_t ***vars = NULL;
+  typedef struct
+  {
+    double *array1;
+    double *array2;
+  } memory_t;
+  memory_t *mem = NULL;
 
   cdoInitialize(argument);
 
@@ -109,13 +118,13 @@ void *Detrend(void *argument)
 	  nalloc += NALLOC_INC;
 	  vdate = (int *) realloc(vdate, nalloc*sizeof(int));
 	  vtime = (int *) realloc(vtime, nalloc*sizeof(int));
-	  vars  = (FIELD ***) realloc(vars, nalloc*sizeof(FIELD **));
+	  vars  = (field_t ***) realloc(vars, nalloc*sizeof(field_t **));
 	}
 
       vdate[tsID] = taxisInqVdate(taxisID1);
       vtime[tsID] = taxisInqVtime(taxisID1);
 
-      vars[tsID] = (FIELD **) malloc(nvars*sizeof(FIELD *));
+      vars[tsID] = (field_t **) malloc(nvars*sizeof(field_t *));
 
       for ( varID = 0; varID < nvars; varID++ )
 	{
@@ -123,7 +132,7 @@ void *Detrend(void *argument)
 	  missval  = vlistInqVarMissval(vlistID1, varID);
 	  nlevel   = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
 
-	  vars[tsID][varID] = (FIELD *) malloc(nlevel*sizeof(FIELD));
+	  vars[tsID][varID] = (field_t *) malloc(nlevel*sizeof(field_t));
 
 	  for ( levelID = 0; levelID < nlevel; levelID++ )
 	    {
@@ -148,8 +157,12 @@ void *Detrend(void *argument)
 
   nts = tsID;
 
-  array1 = (double *) malloc(nts*sizeof(double));
-  array2 = (double *) malloc(nts*sizeof(double));
+  mem = (memory_t *) malloc(ompNumThreads*sizeof(memory_t));
+  for ( i = 0; i < ompNumThreads; i++ )
+    {
+      mem[i].array1 = (double *) malloc(nts*sizeof(double));
+      mem[i].array2 = (double *) malloc(nts*sizeof(double));
+    }
 
   for ( varID = 0; varID < nvars; varID++ )
     {
@@ -159,21 +172,33 @@ void *Detrend(void *argument)
       nlevel   = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
       for ( levelID = 0; levelID < nlevel; levelID++ )
 	{
+#if defined (_OPENMP)
+#pragma omp parallel for default(shared) private(i, ompthID, tsID)
+#endif
 	  for ( i = 0; i < gridsize; i++ )
 	    {
+#if defined (_OPENMP)
+              ompthID = omp_get_thread_num();
+#else
+              ompthID = 0;
+#endif
 	      for ( tsID = 0; tsID < nts; tsID++ )
-		array1[tsID] = vars[tsID][varID][levelID].ptr[i];
+		mem[ompthID].array1[tsID] = vars[tsID][varID][levelID].ptr[i];
 
-	      detrend(nts, missval, array1, array2);
+	      detrend(nts, missval, mem[ompthID].array1, mem[ompthID].array2);
 
 	      for ( tsID = 0; tsID < nts; tsID++ )
-		vars[tsID][varID][levelID].ptr[i] = array2[tsID];
+		vars[tsID][varID][levelID].ptr[i] = mem[ompthID].array2[tsID];
 	    }
 	}
     }
 
-  if ( array1 ) free(array1);
-  if ( array2 ) free(array2);
+  for ( i = 0; i < ompNumThreads; i++ )
+    {
+      free(mem[i].array1);
+      free(mem[i].array2);
+    }
+  free(mem);
 
   for ( tsID = 0; tsID < nts; tsID++ )
     {
