@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2008 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -144,7 +144,7 @@ static void gen_index(int gridID1, int gridID2, int *index)
       free(yvals2);
     }
   else
-    cdoAbort("Data on %s grid unsupported!", gridNamePtr(gridtype1));
+    cdoAbort("Unsupported grid type: %s", gridNamePtr(gridtype1));
 }
 
 
