@@ -85,7 +85,7 @@ void printAtts(int vlistID, int varID)
 
 void *Filedes(void *argument)
 {
-  int GRIDDES, GRIDDES2, ZAXISDES, VCT, PARDES, TAXISDES, FILEDES, VLIST, PARTAB, PARTAB2;
+  int GRIDDES, GRIDDES2, ZAXISDES, VCT, VCT2, PARDES, FILEDES, VLIST, PARTAB, PARTAB2;
   int operatorID;
   int streamID = 0;
   int zaxisID;
@@ -95,15 +95,15 @@ void *Filedes(void *argument)
 
   cdoInitialize(argument);
 
-  GRIDDES  = cdoOperatorAdd("griddes",  0, 0, NULL);
-  GRIDDES2 = cdoOperatorAdd("griddes2", 0, 0, NULL);
-  ZAXISDES = cdoOperatorAdd("zaxisdes", 0, 0, NULL);
-  TAXISDES = cdoOperatorAdd("taxisdes", 0, 0, NULL);
-  VCT      = cdoOperatorAdd("vct",      0, 0, NULL);
-  PARDES   = cdoOperatorAdd("pardes",   0, 0, NULL);
-  FILEDES  = cdoOperatorAdd("filedes",  0, 0, NULL);
-  VLIST    = cdoOperatorAdd("vlist",    0, 0, NULL);
-  PARTAB   = cdoOperatorAdd("partab",   0, 0, NULL);
+  GRIDDES  = cdoOperatorAdd("griddes",   0, 0, NULL);
+  GRIDDES2 = cdoOperatorAdd("griddes2",  0, 0, NULL);
+  ZAXISDES = cdoOperatorAdd("zaxisdes",  0, 0, NULL);
+  VCT      = cdoOperatorAdd("vct",       0, 0, NULL);
+  VCT2     = cdoOperatorAdd("vct2",      0, 0, NULL);
+  PARDES   = cdoOperatorAdd("pardes",    0, 0, NULL);
+  FILEDES  = cdoOperatorAdd("filedes",   0, 0, NULL);
+  VLIST    = cdoOperatorAdd("vlist",     0, 0, NULL);
+  PARTAB   = cdoOperatorAdd("partab",    0, 0, NULL);
   PARTAB2  = cdoOperatorAdd("partab2",   0, 0, NULL);
 
   operatorID = cdoOperatorID();
@@ -129,108 +129,7 @@ void *Filedes(void *argument)
       for ( index = 0; index < nzaxis; index++ )
 	zaxisPrint(vlistZaxis(vlistID, index));
     }
-  else if ( operatorID == TAXISDES )
-    {
-      int vdate, vtime, ntsteps, nrecs;
-      int year, month, day, hour, minute, second;
-      int taxisID, tsID;
-
-      taxisID = vlistInqTaxis(vlistID);
-      ntsteps = vlistNtsteps(vlistID);
-
-      fprintf(stdout, "   Time axis  : ");
-      if ( taxisInqType(taxisID) == TAXIS_RELATIVE )
-	fprintf(stdout, "relative");
-      else if ( taxisInqType(taxisID) == TAXIS_ABSOLUTE )
-	fprintf(stdout, "absolute");
-      else
-	fprintf(stdout, "unknown");
-      fprintf(stdout, "\n");
-
-      taxisID = vlistInqTaxis(vlistID);
-
-      if ( ntsteps != 0 )
-	{
-	  if ( ntsteps == CDI_UNDEFID )
-	    fprintf(stdout, "   Time steps :  unlimited\n");
-	  else
-	    fprintf(stdout, "   Time steps :  %d\n", ntsteps);
-
-	  if ( taxisID != CDI_UNDEFID )
-	    {
-	      int calendar, unit;
-
-	      if ( taxisInqType(taxisID) == TAXIS_RELATIVE )
-		{
-		  vdate = taxisInqRdate(taxisID);
-		  vtime = taxisInqRtime(taxisID);
-
-		  decode_date(vdate, &year, &month, &day);
-		  decode_time(vtime, &hour, &minute, &second);
-
-		  fprintf(stdout, "     RefTime = "DATE_FORMAT" "TIME_FORMAT,
-			  year, month, day, hour, minute, second);
-		      
-		  unit = taxisInqTunit(taxisID);
-		  if ( unit != CDI_UNDEFID )
-		    {
-		      if ( unit == TUNIT_YEAR )
-			fprintf(stdout, "  Units = years");
-		      else if ( unit == TUNIT_MONTH )
-			fprintf(stdout, "  Units = months");
-		      else if ( unit == TUNIT_DAY )
-			fprintf(stdout, "  Units = days");
-		      else if ( unit == TUNIT_HOUR )
-			fprintf(stdout, "  Units = hours");
-		      else if ( unit == TUNIT_MINUTE )
-			fprintf(stdout, "  Units = minutes");
-		      else if ( unit == TUNIT_SECOND )
-			fprintf(stdout, "  Units = seconds");
-		      else
-			fprintf(stdout, "  Units = unknown");
-		    }
-	      
-		  calendar = taxisInqCalendar(taxisID);
-		  if ( calendar != CDI_UNDEFID )
-		    {
-		      if      ( calendar == CALENDAR_STANDARD )
-			fprintf(stdout, "  Calendar = STANDARD");
-		      else if ( calendar == CALENDAR_PROLEPTIC )
-			fprintf(stdout, "  Calendar = PROLEPTIC");
-		      else if ( calendar == CALENDAR_360DAYS )
-			fprintf(stdout, "  Calendar = 360DAYS");
-		      else if ( calendar == CALENDAR_365DAYS )
-			fprintf(stdout, "  Calendar = 365DAYS");
-		      else if ( calendar == CALENDAR_366DAYS )
-			fprintf(stdout, "  Calendar = 366DAYS");
-		      else
-			fprintf(stdout, "  Calendar = unknown");
-		    }
-
-		  fprintf(stdout, "\n");
-		}
-	    }
-
-	  fprintf(stdout, "  time verification time           lower bound           upper bound\n");
-	  fprintf(stdout, "  step  YYYY-MM-DD hh:mm:ss   YYYY-MM-DD hh:mm:ss   YYYY-MM-DD hh:mm:ss\n");
-
-	  tsID = 0;
-	  while ( (nrecs = streamInqTimestep(streamID, tsID)) )
-	    {
-	      vdate = taxisInqVdate(taxisID);
-	      vtime = taxisInqVtime(taxisID);
-
-	      decode_date(vdate, &year, &month, &day);
-	      decode_time(vtime, &hour, &minute, &second);
-
-	      tsID++;
-	      fprintf(stdout, " %5d "DATE_FORMAT" "TIME_FORMAT,
-		      tsID, year, month, day, hour, minute, second);
-	      fprintf(stdout, "\n");
-	    }
-	}
-    }
-  else if ( operatorID == VCT )
+  else if ( operatorID == VCT || operatorID == VCT2 )
     {
       for ( index = 0; index < nzaxis; index++)
 	{
@@ -245,11 +144,35 @@ void *Filedes(void *argument)
 	      vct     = zaxisInqVctPtr(zaxisID);
 		
 	      if ( vctsize%2 == 0 )
-		for ( i = 0; i < vctsize/2; i++ )
-		  fprintf(stdout, "%5d %25.17f %25.17f\n", i, vct[i], vct[vctsize/2+i]);
+		{
+		  if ( operatorID == VCT )
+		    {
+		      for ( i = 0; i < vctsize/2; i++ )
+			fprintf(stdout, "%5d %25.17f %25.17f\n", i, vct[i], vct[vctsize/2+i]);
+		    }
+		  else
+		    {
+		      int nbyte0, nbyte;
+		      fprintf(stdout, "vctsize   = %d\n", vctsize);
+		      nbyte0 = fprintf(stdout, "vct       = ");
+		      nbyte = nbyte0;
+		      for ( i = 0; i < vctsize; i++ )
+			{
+			  if ( nbyte > 70 || i == vctsize/2 )
+			    {
+			      fprintf(stdout, "\n%*s", nbyte0, "");
+			      nbyte = nbyte0;
+			    }
+			  nbyte += fprintf(stdout, "%.9g ", vct[i]);
+			}
+		      fprintf(stdout, "\n");
+		    }
+		}
 	      else
 		for ( i = 0; i < vctsize; i++ )
 		  fprintf(stdout, "%5d %25.17f\n", i, vct[i]);
+
+	      break;
 	    }
 	}
     }
