@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2009 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,7 @@
 #include "interpol.h"
 
 
-void fillmiss(FIELD *field1, FIELD *field2, int nfill)
+void fillmiss(field_t *field1, field_t *field2, int nfill)
 {
   static char func[] = "fillmiss";
   int gridID, nx, ny, i, j;
@@ -152,7 +152,7 @@ void *Fillmiss(void *argument)
   int gridsize;
   int vlistID1, vlistID2;
   int gridID1 = -1;
-  FIELD field1, field2;
+  field_t field1, field2;
   int taxisID1, taxisID2;
   int nmiss, i, nfill = 1;
 
