@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2008 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2009 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -47,7 +47,7 @@ static void invertLonDes(int vlistID)
   int ilat, ilon;
   int gridtype, nv, iv;
   double *xv1, *xv2;
-  double *xb1, *xb2;;
+  double *xb1, *xb2;
 
   ngrids = vlistNgrids(vlistID);
   for ( index = 0; index < ngrids; index++ )
@@ -146,7 +146,7 @@ static void invertLatDes(int vlistID)
   int ilat, ilon;
   int gridtype, nv, iv;
   double *yv1, *yv2;
-  double *yb1, *yb2;;
+  double *yb1, *yb2;
 
   ngrids = vlistNgrids(vlistID);
   for ( index = 0; index < ngrids; index++ )
