@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2009 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -331,7 +331,6 @@ int gengridcell(int gridID1, int gridsize2, int *cellidx)
   return (gridID2);
 }
 
-
 static
 int genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int *lon21, int *lon22)
 {
@@ -503,7 +502,8 @@ int genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int
       for ( *lon21 = 0; *lon21 < nlon1 && xvals1[*lon21] < xlon1; (*lon21)++ );
       for ( *lon22 = *lon21; *lon22 < nlon1 && xvals1[*lon22] < xlon2; (*lon22)++ );
 
-      (*lon22)--;
+      if ( *lon22 >= nlon1 ) (*lon22)--;
+
       xlon1 -= 360;
       xlon2 -= 360;
 
@@ -550,7 +550,6 @@ int genlonlatgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int
   if ( (*lon22 - *lon21 + 1 <= 0)  && (*lon12 - *lon11 + 1 <= 0)  )
     cdoAbort("Longitudinal dimension is too small!");
   */
-
   free(xvals1);
   free(yvals1);
 
@@ -669,22 +668,22 @@ int genindexgrid(int gridID1, int *lat1, int *lat2, int *lon11, int *lon12, int
 
   if ( *lat1 < 1 )
     {
-      cdoWarning("first latitude index out of range. Set to 1.");
+      cdoWarning("First latitude index out of range, set to 1!");
       *lat1 = 1;
     }
   if ( *lat2 > nlat1 )
     {
-      cdoWarning("last latitude index out of range. Set to %d.", nlat1);
+      cdoWarning("Last latitude index out of range, set to %d!", nlat1);
       *lat2 = nlat1;
     }
   if ( *lon11 < 1 )
     {
-      cdoWarning("first longitude index out of range. Set to 1.");
+      cdoWarning("First longitude index out of range, set to 1!");
       *lon11 = 1;
     }
   if ( *lon12 > nlon1+1 )
     {
-      cdoWarning("last longitude index out of range. Set to %d.", nlon1);
+      cdoWarning("Last longitude index out of range, set to %d!", nlon1);
       *lon12 = nlon1;
     }
 
@@ -833,9 +832,10 @@ void *Selbox(void *argument)
 	}
       else
 	{
-	  cdoPrint("%s grid unsupported!", gridNamePtr(gridtype));
+	  cdoPrint("Unsupported grid type: %s", gridNamePtr(gridtype));
 	  if ( gridtype == GRID_GAUSSIAN_REDUCED )
 	    cdoPrint("Use option -R to convert Gaussian reduced grid to a regular grid!");
+	  cdoAbort("Unsupported grid type!");
 	}
     }
 
