@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2009 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2003-2010 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -139,7 +139,7 @@ void *Writegrid(void *argument)
 	  free(yvals);
 	}
       else
-	cdoAbort("%s grid unsupported!", gridNamePtr(gridtype));
+	cdoAbort("Unsupported grid type: %s", gridNamePtr(gridtype));
     }
 
   streamClose(streamID);
