@@ -41,6 +41,7 @@ typedef struct {
   int     size;
   int     xsize;
   int     ysize;
+  int     lcomplex;
   int     def_xfirst;
   int     def_yfirst;
   int     def_xlast;
@@ -55,10 +56,10 @@ typedef struct {
   char    ylongname[128];
   char    yunits[128];
 }
-GRID;
+grid_t;
 
-void gridInit(GRID *grid);
-int gridDefine(GRID grid);
+void gridInit(grid_t *grid);
+int gridDefine(grid_t grid);
 
 int gridFromNCfile(const char *gridfile);
 int gridFromH5file(const char *gridfile);
