@@ -31,7 +31,8 @@ FILE *old, *new;
 #endif
 
 
-static long int_index(long n, double *x1, double x2)
+static
+long int_index(long n, double *x1, double x2)
 {
   long klo, khi, k;
 
@@ -56,8 +57,8 @@ static long int_index(long n, double *x1, double x2)
   return (klo);
 }
 
-
-static double esat(double temperature)
+static
+double esat(double temperature)
 {
   double zes;
   double es;
@@ -80,13 +81,13 @@ static double esat(double temperature)
 
 /* Source from INTERA */
 void hetaeta(int ltq, int ngp, const int *imiss,
-	     int nlev1, const double *ah1, const double *bh1,
-             const double *fis1, const double *ps1, 
-             const double *t1, const double *q1,
-             int nlev2, const double *ah2, const double *bh2, 
-             const double *fis2, double * restrict ps2, 
+	     int nlev1, const double * restrict ah1, const double * restrict bh1,
+             const double * restrict fis1, const double * restrict ps1, 
+             const double * restrict t1, const double * restrict q1,
+             int nlev2, const double * restrict ah2, const double * restrict bh2, 
+             const double * restrict fis2, double * restrict ps2, 
              double * restrict t2, double * restrict q2,
-	     int nvars, const double **vars1, double ** restrict vars2,
+	     int nvars, double ** restrict  vars1, double ** restrict vars2,
 	     double * restrict tscor, double * restrict pscor,
 	     double * restrict secor)
 {
@@ -97,7 +98,7 @@ void hetaeta(int ltq, int ngp, const int *imiss,
   double pbl_lim, pbl_lim_need;
   long jblt, jjblt;
   long k, iv, ij, ijk, ijk1, ijk2;
-  long jlev = 0, jlevr = 0, jnop;
+  long jlev = 0, jlevr, jnop;
   double /* *etah1,*/ *ph1, *lnph1, *fi1;
   double *af1, *bf1, *etaf1, *pf1, *lnpf1;
   double *tv1, *theta1, *rh1;
@@ -207,7 +208,7 @@ void hetaeta(int ltq, int ngp, const int *imiss,
 	{
 	  if ( nvars > MAX_VARS )
 	    {
-	      fprintf(stderr, "To many vars (max = %d)!\n", MAX_VARS);
+	      fprintf(stderr, "Too many vars (max = %d)!\n", MAX_VARS);
 	      exit(-1);
 	    }
 	  vars_pbl_2[i]  = (double **) malloc(nvars*sizeof(double *));
@@ -264,8 +265,8 @@ void hetaeta(int ltq, int ngp, const int *imiss,
 
   w1     = (double *) malloc(nlev2*sizeof(double));
   w2     = (double *) malloc(nlev2*sizeof(double));
-  jl1    = (long *)    malloc(nlev2*sizeof(long));
-  jl2    = (long *)    malloc(nlev2*sizeof(long));
+  jl1    = (long *)   malloc(nlev2*sizeof(long));
+  jl2    = (long *)   malloc(nlev2*sizeof(long));
 
 
   /******* set coordinate system ETA's, A's, B's
@@ -461,7 +462,7 @@ void hetaeta(int ltq, int ngp, const int *imiss,
 	  zdff = fi1[jlev+1]-fis2[ij];
       
 	  /* get the number of points used for estimation of regression coefficients */
-      
+	  jlevr = 0;
 	  for ( k = jlev-1; k > 0; --k )
 	    {
 	      jlevr = k;
