@@ -42,42 +42,44 @@
 
 
 typedef struct {
-  int func;
-  int intval;
+  int         func;
+  int         intval;
   const char *name;
   const char *enter;
 }
-OPERATOR;
+operator_t;
 
 typedef struct {
-  int      threadID;
-  int      nchild;
-  int      nstream;
-  int      streams[MAX_STREAM];
-  double   s_utime;
-  double   s_stime;
-  double   a_utime;
-  double   a_stime;
-  double   cputime;
+#if  defined  (HAVE_LIBPTHREAD)
+  pthread_t threadID;
+#endif
+  short      nchild;
+  short      nstream;
+  short      streams[MAX_STREAM];
+  double     s_utime;
+  double     s_stime;
+  double     a_utime;
+  double     a_stime;
+  double     cputime;
 
-  off_t    nvals;
-  int      nvars;
-  int      ntimesteps;
-  int      streamCnt;
-  char   **streamNames;
-  char    *xoperator;
-  char    *operatorName;
-  char    *operatorArg;
-  int      oargc;
-  char    *oargv[MAX_ARGC];
-  char     prompt[64];
-  int      noper;
-  OPERATOR Operator[MAX_OPERATOR];
+  off_t      nvals;
+  short      nvars;
+  int        ntimesteps;
+  short      streamCnt;
+  char     **streamNames;
+  char      *xoperator;
+  char      *operatorName;
+  char      *operatorArg;
+  int        oargc;
+  char      *oargv[MAX_ARGC];
+  char       prompt[64];
+  short      noper;
+  operator_t operator[MAX_OPERATOR];
 }
-PROCESS;
+process_t;
 
 
-static PROCESS Process[MAX_PROCESS];
+static process_t Process[MAX_PROCESS];
 
 static int NumProcess = 0;
 
@@ -103,7 +105,7 @@ int processCreate(void)
     Error(func, "Limit of %d processes reached!", MAX_PROCESS);
 
 #if  defined  (HAVE_LIBPTHREAD)
-  Process[processID].threadID     = (int) pthread_self();
+  Process[processID].threadID     = pthread_self();
 #endif
   Process[processID].nstream      = 0;
   Process[processID].nchild       = 0;
@@ -129,12 +131,12 @@ int processSelf(void)
   static char func[] = "processSelf";
   int processID = 0;
 #if  defined  (HAVE_LIBPTHREAD)
-  int thID = (int) pthread_self();
+  pthread_t thID = pthread_self();
 
   pthread_mutex_lock(&processMutex);
 
   for ( processID = 0; processID < NumProcess; processID++ )
-    if ( Process[processID].threadID == thID ) break;
+    if ( pthread_equal(Process[processID].threadID, thID) ) break;
 
   if ( processID == NumProcess )
     {
@@ -331,8 +333,8 @@ const char *processOperator(void)
   return (Process[processID].xoperator);
 }
 
-
-static char *getOperatorArg(const char *xoperator)
+static
+char *getOperatorArg(const char *xoperator)
 {
   static char func[] = "getOperatorArg";
   char *commapos;
@@ -357,11 +359,10 @@ static char *getOperatorArg(const char *xoperator)
   return (operatorArg);
 }
 
-
 static int skipInputStreams(int argc, char *argv[], int globArgc, int nstreams);
 
-
-static int getGlobArgc(int argc, char *argv[], int globArgc)
+static
+int getGlobArgc(int argc, char *argv[], int globArgc)
 {
   int streamInCnt;
   int streamOutCnt;
@@ -391,8 +392,11 @@ static int getGlobArgc(int argc, char *argv[], int globArgc)
       printf("%d %d %d\n", i, argc, globArgc);
       if ( i < argc )
       */
-	Error(processInqPrompt(),
-	      "Unlimited input streams not allowed in CDO pipes (Operator %s)!", opername);
+      streamInCnt = 1;
+      /*
+      Error(processInqPrompt(),
+	    "Unlimited input streams not allowed in CDO pipes (Operator %s)!", opername);
+      */
     }
 
   if ( streamOutCnt != 1 )
@@ -408,8 +412,8 @@ static int getGlobArgc(int argc, char *argv[], int globArgc)
   return (globArgc);
 }
 
-
-static int skipInputStreams(int argc, char *argv[], int globArgc, int nstreams)
+static
+int skipInputStreams(int argc, char *argv[], int globArgc, int nstreams)
 {
   while ( nstreams > 0 )
     {
@@ -431,8 +435,8 @@ static int skipInputStreams(int argc, char *argv[], int globArgc, int nstreams)
   return (globArgc);
 }
 
-
-static int getStreamCnt(int argc, char *argv[])
+static
+int getStreamCnt(int argc, char *argv[])
 {
   int streamCnt = 0;
   int globArgc = 1;
@@ -452,8 +456,8 @@ static int getStreamCnt(int argc, char *argv[])
   return (streamCnt);
 }
 
-
-static void setStreamNames(int argc, char *argv[])
+static
+void setStreamNames(int argc, char *argv[])
 {
   static char func[] = "setStreamNames";
   int processID = processSelf();
@@ -489,8 +493,8 @@ static void setStreamNames(int argc, char *argv[])
     }
 }
 
-
-static void checkStreamCnt(void)
+static
+void checkStreamCnt(void)
 {
   int processID = processSelf();
   int streamInCnt, streamOutCnt;
@@ -541,7 +545,8 @@ static void checkStreamCnt(void)
 
 #define  MAX_ARGV  8192
 
-static void setStreams(const char *argument)
+static
+void setStreams(const char *argument)
 {
   static char func[] = "setStreams";
   int processID = processSelf();
@@ -775,10 +780,10 @@ int cdoOperatorAdd(const char *name, int func, int intval, const char *enter)
 
   if ( operID < MAX_OPERATOR )
     {
-      Process[processID].Operator[operID].func   = func;
-      Process[processID].Operator[operID].intval = intval;
-      Process[processID].Operator[operID].name   = name;
-      Process[processID].Operator[operID].enter  = enter;
+      Process[processID].operator[operID].func   = func;
+      Process[processID].operator[operID].intval = intval;
+      Process[processID].operator[operID].name   = name;
+      Process[processID].operator[operID].enter  = enter;
 
       Process[processID].noper++;
     }
@@ -799,8 +804,8 @@ int cdoOperatorID(void)
   if ( Process[processID].noper > 0 )
     {
       for ( operID = 0; operID < Process[processID].noper; operID++ )
-	if ( Process[processID].Operator[operID].name )
-	  if ( strcmp(Process[processID].operatorName, Process[processID].Operator[operID].name) == 0 ) break;
+	if ( Process[processID].operator[operID].name )
+	  if ( strcmp(Process[processID].operatorName, Process[processID].operator[operID].name) == 0 ) break;
 
       if ( operID == Process[processID].noper )
 	cdoAbort("Operator not callable by this name!");
@@ -818,7 +823,7 @@ int cdoOperatorFunc(int operID)
 {
   int processID = processSelf();
 
-  return (Process[processID].Operator[operID].func);
+  return (Process[processID].operator[operID].func);
 }
 
 
@@ -826,7 +831,7 @@ int cdoOperatorIntval(int operID)
 {
   int processID = processSelf();
 
-  return (Process[processID].Operator[operID].intval);
+  return (Process[processID].operator[operID].intval);
 }
 
 
@@ -834,7 +839,7 @@ const char *cdoOperatorName(int operID)
 {
   int processID = processSelf();
 
-  return (Process[processID].Operator[operID].name);
+  return (Process[processID].operator[operID].name);
 }
 
 
@@ -842,5 +847,13 @@ const char *cdoOperatorEnter(int operID)
 {
   int processID = processSelf();
 
-  return (Process[processID].Operator[operID].enter);
+  return (Process[processID].operator[operID].enter);
+}
+
+
+int cdoStreamNumber()
+{
+  int processID = processSelf();
+
+  return (operatorStreamNumber(Process[processID].operatorName));
 }
